summaryrefslogtreecommitdiff
path: root/cmd/mvebu/bubt.c
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/mvebu/bubt.c')
-rw-r--r--cmd/mvebu/bubt.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/cmd/mvebu/bubt.c b/cmd/mvebu/bubt.c
index 84d2d531f0..6c68620d14 100644
--- a/cmd/mvebu/bubt.c
+++ b/cmd/mvebu/bubt.c
@@ -423,8 +423,10 @@ static int is_usb_active(void)
#ifdef CONFIG_CMD_NET
static size_t tftp_read_file(const char *file_name)
{
- /* update global variable load_addr before tftp file from network */
- load_addr = get_load_addr();
+ /*
+ * update global variable image_load_addr before tftp file from network
+ */
+ image_load_addr = get_load_addr();
return net_loop(TFTPGET);
}